ConstantFunctions class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convertKhString(
int n) → String -
Required Integer parameter Example: convertKhString(1) Result: ១ -
converToKhNum(
int n) → int -
getKhmerDay(
DateTime date, {dynamic isShort = false}) → String -
getKhmerMonth(
DateTime date) → String -
getKhmerMonthByMonthNum(
int monthNum) → String -
getLatinDay(
DateTime date, {dynamic isShort = false}) → String -
getLatinMonth(
DateTime date, {dynamic isShort = false}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverseKhNum(
String n) → int -
Required String parameter Example: reverseKhNum("១") Result: 1 -
reverseKhString(
String n) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited